from django.views.generic import View
from django.http import JsonResponse
from django.conf import settings
import inspect

import GeoffreyApp.api.commands as commands
from GeoffreyApp.errors import *


def run_command(request, command, req_type):
    command = command.lower()
    try:
        if command in commands.command_dict[req_type]:
            response = commands.command_dict[req_type][command]["func"](**request.dict())
        else:
            raise CommandNotFound
    except Exception as e:
        response = {"error": e.__class__.__name__}

    return JsonResponse(response, safe=False)


class CommandAPI(View):
    def get(self, request, command):
        get = request.GET
        if command.lower() == "commands":
            return JsonResponse(command.commands_dict)
        else:
            return run_command(get, command, "GET")

    def post(self, request, command):
        post = request.POST
        return run_command(post, command, "POST")

    def delete(self, request, command):
        delete = request.DELETE
        return run_command(delete, command, "DELETE")


class SettingsAPI(View):
    def get(self, request):
        response = {
            "BOT_PREFIX": getattr(settings, 'BOT_PREFIX', '?'),
            "ERROR_USERS": getattr(settings, 'ERROR_USERS', []),
            "MOD_RANK": getattr(settings, 'MOD_RANK', []),
            "DEFAULT_STATUS": getattr(settings, 'DEFAULT_STATUS', 'sed')
        }

        return JsonResponse(response)



